@@ -7,11 +7,11 @@ from dateutil.relativedelta import relativedelta
 from platformdirs import user_cache_dir
 
 # iNaturalist URLs
-API_V0_BASE_URL = 'https://www.inaturalist.org'
-API_V1_BASE_URL = 'https://api.inaturalist.org/v1'
-API_V2_BASE_URL = 'https://api.inaturalist.org/v2'
+API_V0 = 'https://www.inaturalist.org'
+API_V1 = 'https://api.inaturalist.org/v1'
+API_V2 = 'https://api.inaturalist.org/v2'
 EXPORT_URL = 'https://www.inaturalist.org/observations/export'
-INAT_BASE_URL = API_V0_BASE_URL
+INAT_BASE_URL = API_V0
 INAT_REPO = 'https://raw.githubusercontent.com/inaturalist/inaturalist/main'
 ICONIC_TAXA_BASE_URL = f'{INAT_REPO}/app/assets/images/iconic_taxa'
 PHOTO_BASE_URL = 'https://static.inaturalist.org/photos'
