@@ -8,7 +8,7 @@ from os.path import expanduser
 from pathlib import Path
 from typing import Dict, Generic, List, Type, TypeVar
 
-from attr import Factory, asdict, define, field, fields, fields_dict
+from attr import Factory, asdict, define, field, fields_dict
 
 from pyinaturalist.constants import (
     DATETIME_SHORT_FORMAT,
@@ -18,7 +18,7 @@ from pyinaturalist.constants import (
     ResponseOrResults,
     TableRow,
 )
-from pyinaturalist.converters import ensure_list
+from pyinaturalist.converters import ensure_list, try_int
 
 T = TypeVar('T', bound='BaseModel')
 TC = TypeVar('TC', bound='BaseModelCollection')
@@ -29,7 +29,7 @@ logger = getLogger(__name__)
 class BaseModel:
     """Base class for data models"""
 
-    id: int = field(default=None, metadata={'doc': 'Unique record ID'})
+    id: int = field(default=None, converter=try_int, metadata={'doc': 'Unique record ID'})
     _nested: bool = field(default=False, repr=False, init=False)
     temp_attrs: List[str] = []
 
@@ -40,9 +40,6 @@ class BaseModel:
         :py:func:`copy.deepcopy` can be used.
         """
         kwargs = obj.to_dict(recurse=False)
-        for a in fields(cls):
-            if a.init is False:
-                kwargs.pop(a.name.lstrip('_'), None)
         return cls(**kwargs)
 
     @classmethod
@@ -70,9 +67,9 @@ class BaseModel:
         return cls.from_json_list(load_json(value))
 
     @classmethod
-    def from_json_list(cls: Type[T], value: ResponseOrResults) -> List[T]:
+    def from_json_list(cls: Type[T], value: ResponseOrResults, **kwargs) -> List[T]:
         """Initialize a collection of model objects from an API response or response results"""
-        return [cls.from_json(item) for item in ensure_list(value)]
+        return [cls.from_json(item, **kwargs) for item in ensure_list(value)]
 
     @property
     def _row(self) -> TableRow:
@@ -84,13 +81,19 @@ class BaseModel:
         """Get the subset of attribute names to show in the model's string representation"""
         raise NotImplementedError
 
-    def to_dict(self, **kwargs) -> JsonResponse:
+    def to_dict(self, recurse: bool = True) -> JsonResponse:
         """Convert this object back to dict format"""
 
         def vs(_inst, _key, value):
             return value.to_dict() if isinstance(value, BaseModel) else value
 
-        obj_dict = asdict(self, value_serializer=vs, retain_collection_types=True, **kwargs)
+        obj_dict = asdict(
+            self,
+            filter=lambda a, _: a.init is True,
+            retain_collection_types=True,
+            recurse=recurse,
+            value_serializer=vs if recurse else None,
+        )
         return {k.lstrip('_'): v for k, v in obj_dict.items()}
 
     def __rich_repr__(self):
