@@ -1,7 +1,15 @@
 from datetime import datetime
+from typing import List
 
 from pyinaturalist.constants import TableRow
-from pyinaturalist.models import BaseModel, LazyProperty, User, datetime_now_field, define_model, field
+from pyinaturalist.models import (
+    BaseModel,
+    LazyProperty,
+    User,
+    datetime_now_field,
+    define_model,
+    field,
+)
 
 
 @define_model
@@ -10,7 +18,7 @@ class Comment(BaseModel):
     from `GET /observations <https://api.inaturalist.org/v1/docs/#!/Observations/get_observations>`_.
     """
 
-    body: str = field(default=None, doc='Comment text')
+    body: str = field(default='', doc='Comment text')
     created_at: datetime = datetime_now_field(doc='Date and time the comment was created')
     hidden: bool = field(default=None, doc='Indicates if the comment is hidden')
     uuid: str = field(default=None, doc='Universally unique identifier')
@@ -22,13 +30,26 @@ class Comment(BaseModel):
     # moderator_actions: List = field(factory=list)
 
     @property
-    def row(self) -> TableRow:
+    def truncated_body(self):
+        """Comment text, truncated"""
+        truncated_body = self.body.replace('\n', ' ').strip()
+        if len(truncated_body) > 50:
+            truncated_body = truncated_body[:47].strip() + '...'
+        return truncated_body
+
+    @property
+    def username(self) -> str:
+        return self.user.login
+
+    @property
+    def _row(self) -> TableRow:
         return {
             'ID': self.id,
-            'User': self.user.login,
+            'User': self.username,
             'Created at': self.created_at,
-            'Comment': self.body,
+            'Comment': self.truncated_body,
         }
 
-    def __str__(self) -> str:
-        return f'{self.user.login} at {self.created_at}: {self.body}'
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['id', 'username', 'created_at', 'truncated_body']
