@@ -3,9 +3,9 @@ from typing import List
 
 from pyinaturalist.constants import JsonResponse, TableRow
 from pyinaturalist.models import (
+    BaseModelCollection,
     Taxon,
     TaxonCount,
-    TaxonCounts,
     define_model,
     define_model_collection,
     field,
@@ -27,38 +27,51 @@ class LifeListTaxon(TaxonCount):
         return int(((70 - self.rank_level) / 5))
 
     @property
-    def row(self) -> TableRow:
+    def _row(self) -> TableRow:
         return {
             'ID': self.id,
             'Rank': self.rank,
-            'Name': {self.name},
+            'Name': self.name,
             'Count': self.count,
         }
 
-    def __str__(self) -> str:
-        padding = " " * self.indent_level
-        return f'[{self.id:<8}] {padding} {self.rank.title()} {self.name}: {self.count}'
+    @property
+    def _str_attrs(self) -> List[str]:
+        return ['id', 'rank', 'name', 'count']
 
 
 @define_model_collection
-class LifeList(TaxonCounts):
+class LifeList(BaseModelCollection):
     """:fa:`dove,style=fas` :fa:`list` A user's life list, based on the schema of ``GET /observations/taxonomy``"""
 
-    count_without_taxon: int = field(default=0)
-    data: List[LifeListTaxon] = field(factory=list, converter=LifeListTaxon.from_json_list)  # type: ignore
+    data: List[LifeListTaxon] = field(factory=list, converter=LifeListTaxon.from_json_list)
+    count_without_taxon: int = field(default=0, doc='Number of observations without a taxon')
     user_id: int = field(default=None)
 
     @classmethod
-    def from_json(cls, value: JsonResponse, user_id: int = None, **kwargs) -> 'LifeListTaxon':  # type: ignore
+    def from_json(cls, value: JsonResponse, user_id: int = None, **kwargs) -> 'LifeList':
         count_without_taxon = value.get('count_without_taxon', 0)
         if 'results' in value:
             value = value['results']
 
-        life_list_json = {'data': value, 'user_id': user_id, 'count_without_taxon': count_without_taxon}
-        return super(LifeList, cls).from_json(life_list_json)  # type: ignore
+        life_list_json = {
+            'data': value,
+            'user_id': user_id,
+            'count_without_taxon': count_without_taxon,
+        }
+        return super(LifeList, cls).from_json(life_list_json)
+
+    def get_count(self, taxon_id: int, count_field='descendant_obs_count') -> int:
+        """Get an observation count for the specified taxon and its descendants, and handle unlisted taxa.
+        **Note:** ``-1`` can be used an alias for ``count_without_taxon``.
+        """
+        if taxon_id == -1:
+            return self.count_without_taxon
+        return super().get_count(taxon_id, count_field=count_field)
 
     def tree(self):
         """**Experimental**
+
         Organize this life list into a taxonomic tree
 
         Returns:
