@@ -11,6 +11,7 @@ from typing import (
     Iterator,
     List,
     Optional,
+    Type,
 )
 
 from requests import Response
@@ -54,7 +55,7 @@ class Paginator(Iterable, AsyncIterable, Generic[T]):
     def __init__(
         self,
         request_function: Callable,
-        model: T,
+        model: Type[T],
         *request_args,
         method: str = 'page',
         limit: int = None,
@@ -82,22 +83,26 @@ class Paginator(Iterable, AsyncIterable, Generic[T]):
         elif self.method == 'page':
             self.kwargs['page'] = 1
 
-        logger.debug(
-            f'Prepared paginated request: {self.request_function.__name__}('
-            f'args={self.request_args}, kwargs={self.kwargs})'
-        )
+        if request_function:
+            log_kwargs = {
+                k: v for k, v in self.kwargs.items() if k not in ['session', 'access_token']
+            }
+            logger.debug(
+                f'Prepared paginated request: {self.request_function.__name__}'
+                f'(args={self.request_args}, kwargs={log_kwargs})'
+            )
 
     async def __aiter__(self) -> AsyncIterator[T]:
         """Iterate over paginated results, with non-blocking requests sent from a separate thread"""
         with ThreadPoolExecutor(max_workers=1) as executor:
             while not self.exhausted:
                 for result in executor.submit(self.next_page).result():
-                    yield self.model.from_json(result)
+                    yield result
 
     def __iter__(self) -> Iterator[T]:
         """Iterate over paginated results"""
         while not self.exhausted:
-            for result in self.model.from_json_list(self.next_page()):
+            for result in self.next_page():
                 yield result
 
     def all(self) -> List[T]:
@@ -113,9 +118,7 @@ class Paginator(Iterable, AsyncIterable, Generic[T]):
         """Get the first result from the query"""
         self.per_page = 1
         results = self.next_page()
-        if not results:
-            return None
-        return self.model.from_json(results[0])
+        return results[0] if results else None
 
     def count(self) -> int:
         """Get the total number of results for this query, without fetching response data.
@@ -125,12 +128,18 @@ class Paginator(Iterable, AsyncIterable, Generic[T]):
         """
         if self.total_results is None:
             kwargs = {**self.kwargs, 'per_page': 0}
-            count_response = self.request_function(*self.request_args, **kwargs)
-            self.total_results = int(count_response['total_results'])
+            response = self.request_function(*self.request_args, **kwargs)
+            if isinstance(response, Response):
+                response = response.json()
+            self.total_results = int(response['total_results'])
         return self.total_results
 
-    def next_page(self) -> List[ResponseResult]:
-        """Get the next page of results"""
+    def next_page(self) -> List[T]:
+        """Get the next page of results, as model objects"""
+        return self.model.from_json_list(self._next_page())
+
+    def _next_page(self) -> List[ResponseResult]:
+        """Get the next page of results, as raw JSON"""
         if self.exhausted:
             return []
 
@@ -205,22 +214,27 @@ class Paginator(Iterable, AsyncIterable, Generic[T]):
 
 
 class IDPaginator(Paginator):
-    """Paginator for endpoints that only accept a single ID per request"""
+    """Paginator for ID-based endpoints that only accept a limited number of IDs per request"""
 
-    def __init__(self, *args, ids: Iterable[IntOrStr] = None, **kwargs):
+    def __init__(self, *args, ids: Iterable[IntOrStr] = None, ids_per_request: int = 1, **kwargs):
         super().__init__(*args, **kwargs)
-        self.ids = deque(ids or [])
-        self.total_results = len(self.ids)
+        if ids_per_request == 1:
+            self.id_batches = deque(ids or [])
+        else:
+            self.id_batches = deque(list(chunkify(ids, ids_per_request)))  # type: ignore
+        self.total_results = len(ids)  # type: ignore
 
-    def next_page(self) -> List[ResponseResult]:
+    def _next_page(self) -> List[ResponseResult]:
         """Get the next record by ID"""
         try:
-            next_id = self.ids.popleft()
+            next_ids = self.id_batches.popleft()
         except IndexError:
             self.exhausted = True
             return []
 
-        response = self.request_function(next_id, *self.request_args, **self.kwargs)
+        response = self.request_function(next_ids, *self.request_args, **self.kwargs)
+        if isinstance(response, Response):
+            response = response.json()
         self.results_fetched += 1
         return response['results'] if 'results' in response else [response]
 
@@ -263,10 +277,18 @@ class AutocompletePaginator(Paginator):
 class JsonPaginator(Paginator):
     """Paginator that returns raw response dicts instead of model objects"""
 
+    def __init__(
+        self,
+        request_function: Callable,
+        *request_args,
+        **kwargs,
+    ):
+        super().__init__(request_function, None, *request_args, **kwargs)  # type: ignore
+
     def __iter__(self) -> Iterator[ResponseResult]:
-        """Iterate over paginated results"""
+        """Iterate over paginated results, and skip conversion to model objects"""
         while not self.exhausted:
-            for result in self.next_page():
+            for result in self._next_page():
                 yield result
 
     def all(self) -> JsonResponse:  # type: ignore
@@ -283,10 +305,33 @@ class JsonPaginator(Paginator):
         return list(unique_results.values())
 
 
+class WrapperPaginator(Paginator):
+    """Paginator class that wraps results that have already been fetched."""
+
+    def __init__(self, results: List[T], *args, **kwargs):
+        super().__init__(None, None, *args, **kwargs)  # type: ignore  # no request_function
+        self.results = results
+        self.results_fetched = self.total_results = len(results)
+
+    def count(self) -> int:
+        return len(self.results)
+
+    def next_page(self):
+        self.exhausted = True
+        return self.results
+
+
+def chunkify(iterable: Iterable, max_size: int) -> Iterator[List]:
+    """Split an iterable into chunks of a max size"""
+    iterable = list(iterable)
+    for index in range(0, len(iterable), max_size):
+        yield iterable[index : index + max_size]
+
+
 def paginate_all(request_function: Callable, *args, method: str = 'page', **kwargs) -> JsonResponse:
     """Get all pages of a multi-page request. Explicit pagination parameters will be overridden.
 
     Returns:
         Response dict containing combined results, in the same format as ``api_func``
     """
-    return JsonPaginator(request_function, None, *args, method=method, **kwargs).all()
+    return JsonPaginator(request_function, *args, method=method, **kwargs).all()
