@@ -5,7 +5,6 @@ from os import getenv
 from typing import Dict, Type
 from unittest.mock import Mock
 
-import forge
 from requests import PreparedRequest, Request, Response, Session
 from requests.adapters import HTTPAdapter
 from requests.utils import default_user_agent
@@ -148,6 +147,119 @@ class ClientSession(CacheMixin, LimiterMixin, Session):
         adapter = HTTPAdapter(max_retries=retry)
         self.mount('https://', adapter)
 
+    def request(  # type: ignore
+        self,
+        method: str,
+        url: str,
+        headers: Dict = None,
+        json: Dict = None,
+        access_token: str = None,
+        allow_redirects: bool = False,
+        allow_str_ids: bool = False,
+        dry_run: bool = False,
+        expire_after: ExpirationTime = None,
+        files: FileOrPath = None,
+        ids: MultiInt = None,
+        raise_for_status: bool = True,
+        refresh: bool = False,
+        stream: bool = False,
+        timeout: int = None,
+        verify: bool = True,
+        **params: RequestParams,
+    ) -> Response:
+        """Wrapper around :py:func:`requests.request` with additional options specific to iNat API requests
+
+        Args:
+            method: HTTP method
+            url: Request URL
+            headers: Request headers
+            json: JSON request body
+            access_token: access_token: the access token, as returned by :func:`get_access_token()`
+            dry_run: Just log the request instead of sending a real request
+            expire_after: How long to keep cached API requests
+            files: File object, path, or URL to upload
+            ids: One or more integer IDs used as REST resource(s) to request
+            refresh: Skip reading from the cache and always fetch a fresh response
+            timeout: Time (in seconds) to wait for a response from the server; if exceeded, a
+                :py:exc:`requests.exceptions.Timeout` will be raised.
+            params: All other keyword arguments will be used as request parameters
+
+        Returns:
+            API response
+        """
+        request = self.prepare_inat_request(
+            method=method,
+            url=url,
+            access_token=access_token,
+            allow_str_ids=allow_str_ids,
+            files=files,
+            headers=headers,
+            ids=ids,
+            json=json,
+            params=params,
+        )
+        logger.info(format_request(request, dry_run))
+
+        # Make a mock request, if specified
+        if dry_run or is_dry_run_enabled(method):
+            return MOCK_RESPONSE
+
+        # Otherwise, send the request
+        response = self.send(
+            request,
+            timeout=timeout,
+            expire_after=expire_after,
+            refresh=refresh,
+            allow_redirects=allow_redirects,
+            stream=stream,
+            verify=verify,
+        )
+        logger.debug(format_response(response))
+
+        if raise_for_status:
+            response.raise_for_status()
+        return response
+
+    def prepare_inat_request(
+        self,
+        method: str,
+        url: str,
+        access_token: str = None,
+        files: FileOrPath = None,
+        headers: Dict = None,
+        ids: MultiInt = None,
+        json: Dict = None,
+        params: RequestParams = None,
+        allow_str_ids: bool = False,
+        **kwargs,
+    ) -> PreparedRequest:
+        """Translate pyinaturalist-specific options into standard request arguments"""
+        # Prepare request params and URL
+        params = preprocess_request_params(params)
+        url = convert_url_ids(url, ids, allow_str_ids)
+
+        # Set auth header
+        headers = headers or {}
+        if access_token:
+            headers['Authorization'] = f'Bearer {access_token}'
+
+        # Convert any datetimes in request body, and read any files or URLs for uploading
+        json = preprocess_request_body(json)
+        if files:
+            files = {'file': ensure_file_obj(files, self)}  # type: ignore
+
+        # Convert into a PreparedRequest
+        request = Request(
+            method=method,
+            url=url,
+            files=files,
+            headers=headers,
+            json=json,
+            params=params,
+            **kwargs,
+        )
+        return super().prepare_request(request)
+
     def send(  # type: ignore  # Adds kwargs not present in Session.send()
         self,
         request: PreparedRequest,
@@ -177,139 +289,28 @@ class ClientSession(CacheMixin, LimiterMixin, Session):
         )
 
 
-def request(
-    method: str,
-    url: str,
-    access_token: str = None,
-    allow_str_ids: bool = False,
-    dry_run: bool = False,
-    expire_after: ExpirationTime = None,
-    files: FileOrPath = None,
-    headers: Dict = None,
-    ids: MultiInt = None,
-    json: Dict = None,
-    raise_for_status: bool = True,
-    refresh: bool = False,
-    session: Session = None,
-    timeout: int = None,
-    **params: RequestParams,
-) -> Response:
-    """Wrapper around :py:func:`requests.request` with additional options specific to iNat API requests
-
-    Args:
-        method: HTTP method
-        url: Request URL
-        access_token: access_token: the access token, as returned by :func:`get_access_token()`
-        dry_run: Just log the request instead of sending a real request
-        expire_after: How long to keep cached API requests
-        files: File object, path, or URL to upload
-        headers: Request headers
-        ids: One or more integer IDs used as REST resource(s) to request
-        json: JSON request body
-        refresh: Skip reading from the cache and always fetch a fresh response
-        session: An existing Session object to use instead of creating a new one
-        timeout: Time (in seconds) to wait for a response from the server; if exceeded, a
-            :py:exc:`requests.exceptions.Timeout` will be raised.
-        params: All other keyword arguments are interpreted as request parameters
-
-    Returns:
-        API response
-    """
-    session = session or get_local_session()
-    request = prepare_request(
-        session=session,
-        method=method,
-        url=url,
-        access_token=access_token,
-        allow_str_ids=allow_str_ids,
-        files=files,
-        headers=headers,
-        ids=ids,
-        json=json,
-        params=params,
-    )
-    logger.info(format_request(request, dry_run))
-
-    # Make a mock request, if specified
-    if dry_run or is_dry_run_enabled(method):
-        return MOCK_RESPONSE
-
-    # Otherwise, send the request
-    session_kwargs = {'timeout': timeout}
-    if isinstance(session, CacheMixin):
-        session_kwargs['expire_after'] = expire_after
-        session_kwargs['refresh'] = refresh
-    response = session.send(request, **session_kwargs)
-    logger.debug(format_response(response))
-
-    if raise_for_status:
-        response.raise_for_status()
-    return response
-
-
-def prepare_request(
-    session: Session,
-    method: str,
-    url: str,
-    access_token: str = None,
-    files: FileOrPath = None,
-    headers: Dict = None,
-    ids: MultiInt = None,
-    json: Dict = None,
-    params: RequestParams = None,
-    allow_str_ids: bool = False,
-    **kwargs,
-) -> PreparedRequest:
-    """Translate ``pyinaturalist``-specific options into standard request arguments"""
-    # Prepare request params and URL
-    params = preprocess_request_params(params)
-    url = convert_url_ids(url, ids, allow_str_ids)
-
-    # Set auth header
-    headers = headers or {}
-    if access_token:
-        headers['Authorization'] = f'Bearer {access_token}'
-
-    # Convert any datetimes in request body, and read any files or URLs for uploading
-    json = preprocess_request_body(json)
-    if files:
-        files = {'file': ensure_file_obj(files, session)}  # type: ignore
-
-    # Convert into a PreparedRequest
-    request = Request(
-        method=method,
-        url=url,
-        files=files,
-        headers=headers,
-        json=json,
-        params=params,
-        **kwargs,
-    )
-    return session.prepare_request(request)
-
-
-@forge.copy(request, exclude='method')
-def delete(url: str, **kwargs) -> Response:
+def delete(url: str, session: ClientSession = None, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.delete` with additional options specific to iNat API requests"""
-    return request('DELETE', url, **kwargs)
+    session = session or get_local_session()
+    return session.request('DELETE', url, **kwargs)
 
 
-@forge.copy(request, exclude='method')
-def get(url: str, **kwargs) -> Response:
+def get(url: str, session: ClientSession = None, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.get` with additional options specific to iNat API requests"""
-    return request('GET', url, **kwargs)
+    session = session or get_local_session()
+    return session.request('GET', url, **kwargs)
 
 
-@forge.copy(request, exclude='method')
-def post(url: str, **kwargs) -> Response:
+def post(url: str, session: ClientSession = None, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.post` with additional options specific to iNat API requests"""
-    return request('POST', url, **kwargs)
+    session = session or get_local_session()
+    return session.request('POST', url, **kwargs)
 
 
-@forge.copy(request, exclude='method')
-def put(url: str, **kwargs) -> Response:
+def put(url: str, session: ClientSession = None, **kwargs) -> Response:
     """Wrapper around :py:func:`requests.put` with additional options specific to iNat API requests"""
-    return request('PUT', url, **kwargs)
+    session = session or get_local_session()
+    return session.request('PUT', url, **kwargs)
 
 
 def clear_cache():
